#!/usr/bin/python3

# Copyright (c) 2017 Canonical Ltd
# Author: Paul Gear
# Description: Run influxdb 'show diagnostics' command to ensure influxdb is running and operational

import json
import os
import pwd
import subprocess
import sys
import traceback


cmd = ['influx', '-execute', 'show diagnostics', '-format', 'json']

authf = os.path.join(
    pwd.getpwuid(os.getuid()).pw_dir,
    '.influx-auth')
username = None
password = None
if os.path.exists(authf):
    with open(authf, 'r') as f:
        username, password = f.readline().split()
if username and password:
    cmd.extend(['-username', username, '-password', password])

try:
    output = subprocess.check_output(cmd)
    j = json.loads(output.decode('utf-8'))
    for o in j['results'][0]['series']:
        if o['name'] == 'system' and o['columns'][-1] == 'uptime':
            print('OK: InfluxDB uptime is {}'.format(o['values'][0][-1]))
            sys.exit(0)
    print('CRITICAL: Unable to determine InfluxDB uptime')
    sys.exit(2)
except Exception as e:
    print('CRITICAL: Exception while attempting to check InfluxDB')
    traceback.print_exc()
    sys.exit(2)
