from charmhelpers.core import hookenv
from charms.reactive import hook
from charms.reactive import RelationBase
from charms.reactive import scopes


class GrafanaProvides(RelationBase):
    scope = scopes.GLOBAL

    @hook('{provides:grafana-source}-relation-{joined,changed}')
    def changed(self):
        self.set_state('{relation_name}.available')

    @hook('{provides:grafana-source}-relation-{broken,departed}')
    def broken(self):
        self.remove_state('{relation_name}.available')

    def provide(self, source_type, url_or_port, description,
                username=None, password=None, database=None):
        """
        :param source_type: The type of Grafana data source (prometheus/mysql)
        :param url_or_port: Details used to build the connection details. If
                            only a port is specified the IP address is pulled
                            from the relating application. If it's a full
                            IP:port string then it's used as is.
        :param description: Used to build the description of this
                            specific datasource in Grafana.
        :param username: A username required to auth for connection.
        :param password: A password required to auth for connection.
        :param database: The database name required to connect to the
                         datasource
        """
        # start out with the old default behavior.
        url = 'http://{}:{}'.format(hookenv.unit_get('private-address'),
                                    url_or_port)

        # This check is built to be py2 and py3 compatible to verify if the
        # value is a string or not. If the value passed is a string with a :
        # then use it as the full URL vs the built one.
        if isinstance(url_or_port, ("".__class__, u"".__class__)):
            if ':' in url_or_port:
                # Then a url with a :port at the end was supplied. Just use it.
                url = url_or_port

        relation_info = {
            'type': source_type,
            'url': url,
            'description': description,
        }

        if source_type == 'mysql' and (not username or not password):
            # Username and password are required for mysql
            hookenv.log('ERROR: Missing MySQL username/password')

        if username and password:
            relation_info['username'] = username
            relation_info['password'] = password

        if database:
            hookenv.log('Adding the database to the relation_info')
            relation_info['database'] = database

        self.set_remote(**relation_info)
