import os
import pwd
import time
import uuid

import influxdb


def get_influxdb_credentials(local_user='root'):
    """Locate and return influx credentials for the given local user."""
    try:
        home_dir = pwd.getpwnam(local_user).pw_dir
        with open(os.path.join(home_dir, '.influx-auth')) as auth:
            line = auth.readline().rstrip()
            if line.count(' ') == 1:
                fields = line.split(' ')
                return fields[0], fields[1]
    except KeyError:
        print('Local user {} not found'.format(local_user))
    except FileNotFoundError:
        print('Credentials for local user {} not found'.format(local_user))

    return None, None


def create_influxdb_user(username, admin=False, local_user=None):
    currentusername, currentpassword = get_influxdb_credentials(local_user=local_user)
    if currentusername and currentusername == username:
        return currentpassword

    adminuser, adminpass = get_influxdb_credentials()
    influx = influxdb.InfluxDBClient(username=adminuser, password=adminpass)
    password = str(uuid.uuid4())

    # Repeat the process of creating teh user until completed or max times
    # reached because sometimes happens a race condition between the influxdb
    # service startup and the client use. In those cases the service is still
    # not fully started when the client is sending the first request
    n = 3
    while True:
        try:
            influx.create_user(username, password, admin=admin)
            break
        except Exception as ex:
            n = n - 1
            if n <= 0:
                raise ex
        time.sleep(5)

    if local_user:
        passwd_entry = pwd.getpwnam(local_user)
        with open(os.path.join(passwd_entry.pw_dir, '.influx-auth'), mode='w') as auth:
            os.chmod(auth.name, 0o0600)
            auth.write('{} {}\n'.format(username, password))
            os.chown(auth.name, passwd_entry.pw_uid, passwd_entry.pw_gid)

    return password
